import React, { createContext, useContext, useEffect, useState } from "react";
import { storeManager } from "./store-manager";

// Create a React Context for the centralized store
const StoreContext = createContext(storeManager.getState());

// Provider for the global state
export const StoreProvider: React.FC<{ children: React.ReactNode }> = ({
  children,
}) => {
  const [state, setState] = useState(storeManager.getState());

  useEffect(() => {
    // Subscribe to store updates
    const unsubscribe = storeManager.subscribe(() => {
      const newState = { ...storeManager.getState() }; // Ensure new reference
      setState(newState); // Trigger React re-render
    });

    // Cleanup on unmount
    return () => {
      unsubscribe();
    };
  }, []);

  return (
    <StoreContext.Provider value={state}>{children}</StoreContext.Provider>
  );
};

// Hook to access the centralized global state via context
export const useGlobalStore = () => {
  return useContext(StoreContext);
};
